def add(a, b):
    return a + b

def div(a, b):
    return a // b

def minus(a, b):
    return a - b

def mult(a, b):
    return a * b
